pub struct ExecutionInstrumentMap {
pub exchange: Keyed<ExchangeIndex, ExchangeId>,
pub assets: FnvIndexSet<ExchangeAsset<Asset>>,
pub instruments: FnvIndexSet<Instrument<Keyed<ExchangeIndex, ExchangeId>, AssetIndex>>,
pub asset_names: FnvHashMap<AssetNameExchange, AssetIndex>,
pub instrument_names: FnvHashMap<InstrumentNameExchange, InstrumentIndex>,
}Expand description
Indexed instrument map used to associate the internal Barter representation of instruments and
assets with the ExecutionClient representation.
Similarly, when the execution manager received an AccountEvent
from the execution API, it needs to determine the internal representation of the associated
assets and instruments.
eg/ InstrumentNameExchange("XBT-USDT") <–> InstrumentIndex(1)
eg/ AssetNameExchange("XBT") <–> AssetIndex(1)
Fields
exchange: Keyed<ExchangeIndex, ExchangeId>The exchange associated with this execution map.
assets: FnvIndexSet<ExchangeAsset<Asset>>Collection of assets available by the engine with their exchange-specific representations. This holds all indexed assets.
instruments: FnvIndexSet<Instrument<Keyed<ExchangeIndex, ExchangeId>, AssetIndex>>Collection of instruments available by the engine. This holds all indexed instruments.
asset_names: FnvHashMap<AssetNameExchange, AssetIndex>Map from exchange-specific asset names to internal asset indices for fast lookups.
instrument_names: FnvHashMap<InstrumentNameExchange, InstrumentIndex>Map from exchange-specific instrument names to internal instrument indices for fast lookups.
Implementations
Sourceimpl ExecutionInstrumentMap
impl ExecutionInstrumentMap
Sourcepub fn new(
exchange: Keyed<ExchangeIndex, ExchangeId>,
instruments: &IndexedInstruments,
) -> Self
pub fn new( exchange: Keyed<ExchangeIndex, ExchangeId>, instruments: &IndexedInstruments, ) -> Self
Construct a new Self using the provided indexed assets and instruments.
pub fn exchange_assets(&self) -> impl Iterator<Item = &AssetNameExchange>
pub fn exchange_instruments( &self, ) -> impl Iterator<Item = &InstrumentNameExchange>
pub fn find_exchange_id( &self, exchange: ExchangeIndex, ) -> Result<ExchangeId, KeyError>
pub fn find_exchange_index( &self, exchange: ExchangeId, ) -> Result<ExchangeIndex, IndexError>
pub fn find_asset_name_exchange( &self, asset: AssetIndex, ) -> Result<&AssetNameExchange, KeyError>
pub fn find_asset_index( &self, asset: &AssetNameExchange, ) -> Result<AssetIndex, IndexError>
pub fn find_instrument_name_exchange( &self, instrument: InstrumentIndex, ) -> Result<&InstrumentNameExchange, KeyError>
pub fn find_instrument_index( &self, instrument: &InstrumentNameExchange, ) -> Result<InstrumentIndex, IndexError>