barter_execution

Module simulated

source
Simulated Exchange and it’s associated simulated ExecutionClient.

Modules

  • Simulated Exchange using public trade Streams to model available market liquidity. Liquidity is then used to match to open client orders.
  • Simulated ExecutionClient implementation that integrates with the Barter SimulatedExchange.

Enums