barter_execution::simulated

Module exchange

source
Simulated Exchange using public trade Streams to model available market liquidity. Liquidity is then used to match to open client orders.

Modules

Structs