barter_execution::simulated::exchange::account

Struct ClientAccount

source
pub struct ClientAccount {
    pub latency: Duration,
    pub fees_percent: f64,
    pub event_account_tx: UnboundedSender<AccountEvent>,
    pub balances: ClientBalances,
    pub orders: ClientOrders,
}
Simulated account state containing ClientBalances and ClientOrders. Details the simulated account fees and latency.

Fields

latency: Durationfees_percent: f64event_account_tx: UnboundedSender<AccountEvent>balances: ClientBalancesorders: ClientOrders

Implementations

source

impl ClientAccount

source

pub fn builder() -> ClientAccountBuilder

Construct a ClientAccountBuilder for configuring a new ClientAccount.

source

pub fn fetch_orders_open( &self, response_tx: Sender<Result<Vec<Order<Open>>, ExecutionError>>, )

Send every Order<Open> for every Instrument to the client.

source

pub fn fetch_balances( &self, response_tx: Sender<Result<Vec<SymbolBalance>, ExecutionError>>, )

Send the Balance for every Symbol to the client.

source

pub fn open_orders( &mut self, open_requests: Vec<Order<RequestOpen>>, response_tx: Sender<Vec<Result<Order<Open>, ExecutionError>>>, )

Execute open order requests and send the response via the provided oneshot::Sender.

source

pub fn try_open_order_atomic( &mut self, request: Order<RequestOpen>, ) -> Result<Order<Open>, ExecutionError>

Execute an open order request, adding it to ClientOrders and updating the associated Balance. Sends an AccountEvent for both the new order and balance update.

source

pub fn check_order_kind_support(kind: OrderKind) -> Result<(), ExecutionError>

Check if the Order<RequestOpen> OrderKind is supported.

source

pub fn cancel_orders( &mut self, cancel_requests: Vec<Order<RequestCancel>>, response_tx: Sender<Vec<Result<Order<Cancelled>, ExecutionError>>>, )

Execute cancel order requests and send the response via the provided oneshot::Sender.

source

pub fn try_cancel_order_atomic( &mut self, request: Order<RequestCancel>, ) -> Result<Order<Cancelled>, ExecutionError>

Execute a cancel order request, removing it from the ClientOrders and updating the associated Balance. Sends an AccountEvent for both the order cancel and balance update.

source

pub fn cancel_orders_all( &mut self, response_tx: Sender<Result<Vec<Order<Cancelled>>, ExecutionError>>, )

Execute a cancel all orders request and send the response via the provided oneshot::Sender.

source

pub fn match_orders(&mut self, instrument: Instrument, trade: PublicTrade)

Determine if the incoming PublicTrade liquidity matches any ClientOrders relating to the Instrument. If there are matches, trades are simulated by client orders being taken.