Simulated Exchange using public trade Streams to model available market liquidity. Liquidity
is then used to match to open client orders.
Modules
SimulatedExchangeaccount balances, open orders, fees, and latency.
Structs
SimulatedExchangethat responds toSimulatedEvents.